package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppBanner;

/**
 * 轮播图Service接口
 * 
 * @author ruoyi
 * @date 2025-03-04
 */
public interface IAppBannerService 
{
    /**
     * 查询轮播图
     * 
     * @param id 轮播图主键
     * @return 轮播图
     */
    public AppBanner selectAppBannerById(Long id);

    /**
     * 查询轮播图列表
     * 
     * @param appBanner 轮播图
     * @return 轮播图集合
     */
    public List<AppBanner> selectAppBannerList(AppBanner appBanner);

    /**
     * 新增轮播图
     * 
     * @param appBanner 轮播图
     * @return 结果
     */
    public int insertAppBanner(AppBanner appBanner);

    /**
     * 修改轮播图
     * 
     * @param appBanner 轮播图
     * @return 结果
     */
    public int updateAppBanner(AppBanner appBanner);

    /**
     * 批量删除轮播图
     * 
     * @param ids 需要删除的轮播图主键集合
     * @return 结果
     */
    public int deleteAppBannerByIds(Long[] ids);

    /**
     * 删除轮播图信息
     * 
     * @param id 轮播图主键
     * @return 结果
     */
    public int deleteAppBannerById(Long id);

    public List<AppBanner> getBannerList();

}
